Default Files
=============

Some information for the running of the GeoSolver is contained in specific .txt files. Typically we have an original file from the AlphaGeometry repository and a new one, where we added new information in the end.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   definitions
   rules
